==> knative-model-5.1.1-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/ServiceBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceBuilder extends io.fabric8.knative.serving.v1beta1.ServiceFluentImpl<io.fabric8.knative.serving.v1beta1.ServiceBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Service,io.fabric8.knative.serving.v1beta1.ServiceBuilder> {

    io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent;
    Boolean validationEnabled;

    public ServiceBuilder() {
        this(true);
    }

    public ServiceBuilder(Boolean validationEnabled) {
        this(new Service(), validationEnabled);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent) {
        this(fluent, true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Service(), validationEnabled);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Service instance) {
        this(fluent, instance, true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Service instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.Service instance) {
        this(instance,true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.Service instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableService build() {
        EditableService buildable = new EditableService(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ServiceBuilder that = (ServiceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/ServiceBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ServiceBuilder extends io.fabric8.knative.serving.v1beta1.ServiceFluentImpl<io.fabric8.knative.serving.v1beta1.ServiceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.serving.v1beta1.Service,io.fabric8.knative.serving.v1beta1.ServiceBuilder> {

    io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent;
    Boolean validationEnabled;

    public ServiceBuilder() {
        this(true);
    }

    public ServiceBuilder(Boolean validationEnabled) {
        this(new Service(), validationEnabled);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent) {
        this(fluent, true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Service(), validationEnabled);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Service instance) {
        this(fluent, instance, true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.ServiceFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Service instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.Service instance) {
        this(instance,true);
    }

    public ServiceBuilder(io.fabric8.knative.serving.v1beta1.Service instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableService build() {
        EditableService buildable = new EditableService(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ServiceBuilder that = (ServiceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
